Package: Matching
Version: 4.10-15
Date: 2024-10-14
Title: Multivariate and Propensity Score Matching with Balance
        Optimization
Authors@R: c(
    person("Jasjeet", "Singh Sekhon", role = c("aut","cre"), email = "jas.sekhon@yale.edu"),
    person("Theo", "Saarinen", role = c("aut"), email = "theo_s@berkeley.edu")
    )        
Maintainer: Jasjeet Singh Sekhon <jas.sekhon@yale.edu>
Description: Provides functions for multivariate and propensity score matching 
             and for finding optimal balance based on a genetic search algorithm. 
             A variety of univariate and multivariate metrics to
             determine if balance has been obtained are also provided. For
             details, see the paper by Jasjeet Sekhon 
             (2007, <doi:10.18637/jss.v042.i07>).
Depends: R (>= 2.6.0), MASS (>= 7.2-1), graphics, grDevices, stats
Suggests: parallel, rgenoud (>= 2.12), testthat
License: GPL-3
URL: https://github.com/JasjeetSekhon/Matching
NeedsCompilation: yes
RoxygenNote: 7.2.1
Packaged: 2024-10-14 13:11:12 UTC; theosaa
Author: Jasjeet Singh Sekhon [aut, cre],
  Theo Saarinen [aut]
Repository: CRAN
Date/Publication: 2024-10-14 14:20:02 UTC
Built: R 4.4.1; aarch64-apple-darwin21.6.0; 2024-11-05 03:15:40 UTC; unix
